sturdy.fs.immutable


compute-dir-sha256clj

(compute-dir-sha256 dir-path)

Deterministically hashes a directory. Hashes each file individually to prevent boundary collisions, then hashes the sorted collection of file hashes.

Deterministically hashes a directory.
Hashes each file individually to prevent boundary collisions,
then hashes the sorted collection of file hashes.
sourceraw docstring

delete-immutable-tree!clj

(delete-immutable-tree! root)

Safely deletes a directory tree that was previously locked via make-immutable!.

Safely deletes a directory tree that was previously locked via make-immutable!.
sourceraw docstring

make-immutable!clj

(make-immutable! path)

Recursively walks a path. Sets files to 444 (read-only) and directories to 555 (read/execute).

Recursively walks a path.
Sets files to 444 (read-only) and directories to 555 (read/execute).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries