(compute-dir-sha256 dir-path)Deterministically hashes a directory. Hashes each file individually to prevent boundary collisions, then hashes the sorted collection of file hashes.
Deterministically hashes a directory. Hashes each file individually to prevent boundary collisions, then hashes the sorted collection of file hashes.
(delete-immutable-tree! root)Safely deletes a directory tree that was previously locked via make-immutable!.
Safely deletes a directory tree that was previously locked via make-immutable!.
(make-immutable! path)Recursively walks a path. Sets files to 444 (read-only) and directories to 555 (read/execute).
Recursively walks a path. Sets files to 444 (read-only) and directories to 555 (read/execute).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |